@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2005 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2006 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2003 Robert Rostek ( tecxx@rrs.at )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
@@ -21,22 +21,18 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA, 02111-1307, USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "DirectoryTreeCtrl.h"
-#endif
-
 #include <wx/log.h>
 
 #include <wx/imaglist.h>
 #include "DirectoryTreeCtrl.h"	// Interface declarations
 #include "muuli_wdr.h"		// Needed for amuleSpecial
-#include "StringFunctions.h" // Needed for unicode2char
+#include <common/StringFunctions.h> // Needed for unicode2char
 #include <wx/event.h>
 
-#include "CFile.h"
+#include "FileFunctions.h"
 
 #ifdef __WXMSW__
 	#define ROOT_CHAR	wxT('\\')
@@ -148,17 +144,7 @@ void CDirectoryTreeCtrl::OnRButtonDown(wxTreeEvent& evt)
 	HitTest(evt.GetPoint(),flags);
 	// this event is launched _after_ checkbox value is set.. if it is set at all
 	if ((hItem.IsOk()) && (flags &  wxTREE_HITTEST_ONITEMICON)) {
-		bool share_it = !IsBold(hItem);
-		CheckChanged(hItem, share_it);
-		Toggle(hItem);
-		wxTreeItemId hChild;
-		wxTreeItemIdValue cookie;
-		hChild = GetFirstChild(hItem,cookie);
-		while (hChild.IsOk()) {
-			MarkChildren(hChild,share_it);
-			hChild=GetNextSibling(hChild);
-		}
-		Toggle(hItem);
+		MarkChildren(hItem,!IsBold(hItem));
 		Refresh();
 	}
 	HasChanged = true;
@@ -167,21 +153,15 @@ void CDirectoryTreeCtrl::OnRButtonDown(wxTreeEvent& evt)
 
 void CDirectoryTreeCtrl::MarkChildren(wxTreeItemId hChild,bool mark)
 {
-	CheckChanged(hChild, mark);
-
-	Toggle(hChild);
-
 	wxTreeItemId hChild2;
 	wxTreeItemIdValue cookie;
 	hChild2 = GetFirstChild(hChild,cookie);
-	int i=0;
 	while(hChild2.IsOk()) {
 		MarkChildren(hChild2,mark);
-		i++;
 		hChild2 = GetNextSibling(hChild2);
 	}
 
-	Toggle(hChild);
+	CheckChanged(hChild, mark);
 }
 
 void CDirectoryTreeCtrl::AddChildItem(wxTreeItemId hBranch, const wxString& strText)
@@ -190,8 +170,6 @@ void CDirectoryTreeCtrl::AddChildItem(wxTreeItemId hBranch, const wxString& strT
 	
 	wxString strDir = GetFullPath(hBranch);
 
-	wxASSERT(!strDir.IsEmpty()); // non-empty path (cannot add root dir)
-	
 	wxASSERT(strText.Find(ROOT_CHAR) == -1); // Folder label has no '/' on the name
 	
 	strDir += strText + ROOT_CHAR;
@@ -300,7 +278,7 @@ void CDirectoryTreeCtrl::SetSharedDirectories(wxArrayString* list)
 		
 		wxASSERT(folder.Len() > 0);
 
-		if (folder.Cmp(ROOT_STRING)) { // no removal for root dir
+		if (folder != ROOT_STRING) { // no removal for root dir
 			while(folder.Len() > 0 && folder.Last() == ROOT_CHAR) {
 				folder.RemoveLast();	// Minus possible trailing slashes.
 			}
