@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2005 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2006 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -20,16 +20,12 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA, 02111-1307, USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
 #ifndef PARTFILE_H
 #define PARTFILE_H
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "PartFile.h"
-#endif
-
 #include <wx/defs.h>		// Needed before any other wx/*.h
 #include <wx/thread.h>		// Needed for wxMutex
 #include <wx/datetime.h>	// Needed for wxDateTime
@@ -48,8 +44,8 @@
 
 class CSearchFile;
 class CUpDownClient;
-class completingThread;
-class CSafeMemFile;
+class CMemFile;
+class CFileDataIO;
 class CED2KFileLink;
 
 
@@ -63,6 +59,14 @@ class CED2KFileLink;
 // This should fix it.
 #define   PARTMET_BAK_EXT wxT(".bak")
 
+enum EPartFileFormat {
+	PMT_UNKNOWN	= 0,
+	PMT_DEFAULTOLD,
+	PMT_SPLITTED,
+	PMT_NEWOLD,
+	PMT_SHAREAZA,
+	PMT_BADFORMAT
+};
 
 struct PartFileBufferedData
 {
@@ -77,6 +81,8 @@ public:
 	CPartFile();
 #ifdef CLIENT_GUI
 	CPartFile(CEC_PartFile_Tag *tag);
+#else 
+	virtual void	SetFileName(const wxString& strmakeFilename);
 #endif
 	CPartFile(CSearchFile* searchresult);  //used when downloading a new file
 	CPartFile(const CED2KFileLink* fileLink);
@@ -85,7 +91,7 @@ public:
 	bool	CreateFromFile(wxString WXUNUSED(directory), wxString WXUNUSED(filename), void* WXUNUSED(pvProgressParam)) {return false;}// not supported in this class
 	void 	SetPartFileStatus(uint8 newstatus);
 	virtual bool LoadFromFile(const CFile* WXUNUSED(file)) const { return false; }
-	bool	WriteToFile(CFile* WXUNUSED(file)) const	{ return false; }
+	bool	WriteToFile(CFileDataIO* WXUNUSED(file))	{ return false; }
 	bool	IsPartFile() const		{ return !(status == PS_COMPLETE); }
 	uint32	Process(uint32 reducedownload, uint8 m_icounter);
 	uint8	LoadPartFile(const wxString& in_directory, const wxString& filename, bool from_backup = false, bool getsizeonly = false);
@@ -105,10 +111,10 @@ public:
 	void	UpdateCompletedInfos();
 
 	bool	GetNextRequestedBlock(CUpDownClient* sender,Requested_Block_Struct** newblocks,uint16* count);
-	void	WritePartStatus(CSafeMemFile* file);
-	void	WriteCompleteSourcesCount(CSafeMemFile* file);
-	bool 	CanAddSource(uint32 userid, uint16 port, uint32 serverip, uint16 serverport, uint8* pdebug_lowiddropped);
-	void	AddSources(CSafeMemFile& sources,uint32 serverip, uint16 serverport);
+	void	WritePartStatus(CMemFile* file);
+	void	WriteCompleteSourcesCount(CMemFile* file);
+	static bool 	CanAddSource(uint32 userid, uint16 port, uint32 serverip, uint16 serverport, uint8* pdebug_lowiddropped = NULL, bool ed2kID = true);
+	void	AddSources(CMemFile& sources, uint32 serverip, uint16 serverport, unsigned origin);
 #ifdef CLIENT_GUI
 	uint8	GetStatus() const { return status; }
 	uint8	GetStatus(bool /*ignorepause = false*/) const { return status; }
@@ -144,9 +150,6 @@ public:
 	// Barry - Added as replacement for BlockReceived to buffer data before writing to disk
 	uint32	WriteToBuffer(uint32 transize, byte *data, uint32 start, uint32 end, Requested_Block_Struct *block);
 	void	FlushBuffer(bool forcewait=false, bool bForceICH = false, bool bNoAICH = false);	
-	// Barry - This will invert the gap list, up to caller to delete gaps when done
-	// 'Gaps' returned are really the filled areas, and guaranteed to be in order
-	void	GetFilledList(CTypedPtrList<CPtrList, Gap_Struct*> *filled);
 
 	// Barry - Is archive recovery in progress
 	volatile bool m_bRecoveringArchive;
@@ -162,8 +165,7 @@ public:
 	void	ResumeFile();
 
 	virtual	CPacket* CreateSrcInfoPacket(const CUpDownClient* forClient);
-	//void	AddClientSources(CMemFile* sources);
-	void    AddClientSources(CSafeMemFile* sources,uint8 sourceexchangeversion);
+	void    AddClientSources(CMemFile* sources, uint8 sourceexchangeversion, unsigned nSourceFrom);
 
 	bool	PreviewAvailable();
 	uint8	GetAvailablePartCount() const	{ return m_availablePartsCount; }
@@ -175,11 +177,6 @@ public:
 	uint32	TotalPacketsSavedDueToICH()const{ return m_iTotalPacketsSavedDueToICH; }
 	bool	IsStopped() const		{ return m_stopped; }
 	bool	IsPaused() const		{ return m_paused; }
-	bool	HasComment() const		{ return hasComment; }
-	bool	HasRating() const		{ return hasRating; }
-	bool	HasBadRating() const		{ return hasBadRating; }
-	void	SetHasComment(bool in)		{ hasComment = in; }
-	void	SetHasRating(bool in)		{ hasRating = in; }
 	void	UpdateFileRatingCommentAvail();
 
 	int	GetCommonFilePenalty();
@@ -196,7 +193,6 @@ public:
 	void	SetAutoDownPriority(bool flag)	{ m_bAutoDownPriority = flag; }
 	void	UpdateAutoDownPriority();
 	uint8	GetDownPriority() const		{ return m_iDownPriority; }
-	completingThread* cthread;
 	bool	GetInsufficient() const		{ return m_insufficient; }
 	
 	void	CompleteFileEnded(int completing_result, wxString* newname);	
@@ -267,6 +263,11 @@ public:
 	 * sources and should not be added to the partfile.
 	 */
 	bool		IsDeadSource(const CUpDownClient* client);
+	
+	/* Kad Stuff */
+	uint16	GetMaxSources() const;
+	uint16	GetMaxSourcePerFileSoft() const;
+	uint16	GetMaxSourcePerFileUDP() const;		 
 
 protected:
 	//! A local list of sources that are invalid for this file.
@@ -288,7 +289,7 @@ protected:
 	bool	CheckFreeDiskSpace( uint32 neededSpace = 0 );
 private:
 	uint32	m_iLastPausePurge;
-	uint16	count;
+	uint16	m_count;
 	uint16	m_anStates[STATES_COUNT];
 	uint16	transferingsrc;
 	uint32  completedsize;
@@ -317,10 +318,7 @@ private:
 	uint32	m_nSavedReduceDownload;
 	bool	m_bPercentUpdated;
 
-	bool	hasRating;
-	bool	hasBadRating;
-	bool	hasComment;
-	uint8 	PerformFileComplete(); // Lord KiRon
+	void	PerformFileComplete();
 
 	uint32		m_lastRefreshedDLDisplay;
 	wxDateTime	m_lastDateChanged;
@@ -370,28 +368,13 @@ private:
 	std::list<CUpDownClient *> m_downloadingSourcesList;
 	static	wxMutex m_FileCompleteMutex;
 
+	/* Kad Stuff */
+	uint32	m_LastSearchTimeKad;
+	uint8	m_TotalSearchesKad;
+
 friend class CPartFile_Encoder;
-friend class completingThread;
 friend class CDownQueueRem;
-};
-
-class completingThread : public wxThread
-{
-public:
-	~completingThread();
-	completingThread(wxString FileName, wxString fullname, uint32 Category, CPartFile* caller);
-	completingThread() { };
-
-private:
-	virtual	bool InitInstance() { return true; }
-	virtual wxThread::ExitCode Entry();
-	uint8 completing_result;
-	uint32 Completing_Category;
-	wxString Completing_FileName;
-	wxString Completing_Fullname;
-	wxString* newname;
-	CPartFile* completing;
-	virtual void OnExit();
+friend class CPartFileConvert;
 };
 
 #endif // PARTFILE_H
