@@ -1,8 +1,8 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2004-2005 aMule Team ( admin@amule.org / http://www.amule.org )
-// Copyright (c) 2004-2005 Marcelo Jimenez ( phoenix@amule.org )
+// Copyright (c) 2004-2006 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2004-2006 Marcelo Jimenez ( phoenix@amule.org )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
 // or contributed by third-party developers are copyrighted by their
@@ -20,28 +20,18 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA, 02111-1307, USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
-
 #ifndef __PROXY_H__
 #define __PROXY_H__
 
-
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "Proxy.h"
-#endif
-
 #include <wx/socket.h>		// For wxSocket*
 #include <wx/string.h>		// For wxString
 
 #include "amuleIPV4Address.h"	// For amuleIPV4address
 #include "StateMachine.h"	// For CStateMachine
 
-#if !wxCHECK_VERSION(2,5,1)
-	#define wxIPaddress wxIPV4address
-#endif
-
 /******************************************************************************/
 
 /*
@@ -516,6 +506,11 @@ public:
 		
 	/* Interface */
 	bool Connect(wxIPaddress &address, bool wait);
+	CSocketClientProxy& Read(void *buffer, wxUint32 nbytes);
+	CSocketClientProxy& Write(const void *buffer, wxUint32 nbytes);
+
+private:
+	wxMutex			m_socketLocker;
 };
 
 //------------------------------------------------------------------------------
@@ -532,8 +527,11 @@ public:
 		const CProxyData *proxyData = NULL);
 		
 	/* Interface */
+	CSocketServerProxy& Read(void *buffer, wxUint32 nbytes);
+	CSocketServerProxy& Write(const void *buffer, wxUint32 nbytes);
 	
 private:
+	wxMutex			m_socketLocker;
 };
 
 //------------------------------------------------------------------------------
@@ -553,9 +551,6 @@ const unsigned int PROXY_UDP_MAXIMUM_OVERHEAD		= PROXY_UDP_OVERHEAD_DOMAIN_NAME;
 
 class CDatagramSocketProxy : public wxDatagramSocket
 {
-#if !wxCHECK_VERSION(2,5,3)
-	DECLARE_ABSTRACT_CLASS(CDatagramSocketProxy)
-#endif
 public:
 	/* Constructor */
 	CDatagramSocketProxy(
@@ -581,8 +576,10 @@ private:
 	CProxySocket		m_proxyTCPSocket;
 	enum UDPOperation	m_lastUDPOperation;
 	unsigned int		m_lastUDPOverhead;
+	wxMutex			m_socketLocker;
 };
 
 /******************************************************************************/
 
 #endif /* __PROXY_H__ */
+
